AnimarkerController class

Inheritance

Constructors

AnimarkerController({required AnimarkerControllerDescription description})

Properties

description → AnimarkerControllerDescription
final
hashCode → int
The hash code for this object.
no setterinherited
observers ↔ List<OnLocationChanged>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracker ↔ Map<MarkerId, IAnilocationTask>
latefinal

Methods

attach({required OnLocationChanged observer}) → void
inherited
detach(OnLocationChanged observer) → void
inherited
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyObservers() → void
inherited
pushMarker(Marker marker) → Future<void>
override
toString() → String
A string representation of this object.
inherited
updateActiveTrip(bool activeTrip) → void
override
updateRadius(double radius) → void
override
updateUseRotation(bool useRotation) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited