SphericalUtil class abstract

Constructors

SphericalUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

angleLerp(double from, double to, double t) → double
angleLerpOptimized(Float32x4 angle, Float32x4 from, double t) → double
angleShortestDistance(double from, double to) → double
bearingBetweenLocations(LatLngInfo latLngFrom, LatLngInfo latLngTo) → double
calculateZoomScale(double densityDpi, double zoomLevel, ILatLng target) → double
computeAngleBetween(ILatLng from, ILatLng to) → num
computeDistanceBetween(ILatLng from, ILatLng to) → num
computeHeading(ILatLng from, ILatLng to) → num
distanceRadians(num lat1, num lng1, num lat2, num lng2) → num
getBearing(ILatLng begin, ILatLng end) → double
interpolate(ILatLng from, ILatLng to, num fraction) → ILatLng
Returns the LatLng which lies the given fraction of the way between the origin LatLng and the destination LatLng. @param from The LatLng from which to start. @param to The LatLng toward which to travel. @param fraction A fraction of the distance to travel. @return The interpolated LatLng.
inverseLerp(double min, double max, double value) → double
inverseLerpOptimized(Float32x4 min, Float32x4 max, Float32x4 delta, bool isEqualValue, Float32x4 value) → Float32x4
latLngtoVector3(ILatLng iLatLng) → Vector3
latRad(dynamic lat) → double
lerpUnclamped(Vector3 min, Vector3 max, double x) → Vector3
lerpUnclampedOptimized(Float32x4 min, Float32x4 max, Float32x4 x) → Float32x4
toVector3(double lat, double lng) → Vector3
vectorInterpolate(ILatLng from, ILatLng to, double t) → ILatLng
vectorInterpolateOptimized(Float32x4 delta, Float32x4 min, double t) → ILatLng
vectorSlerp(List<double> inputs, List<Vector3> results, double desiredInput) → Vector3
vectorSlerpOptimized(Float32x4List preList, Float32x4 last, double step, double t) → Float32x4
vectorToPolar(Vector3 i) → ILatLng
vectorToPolarOptimized(Float32x4 vector) → ILatLng
zoom(dynamic mapPx, dynamic worldPx, dynamic fraction) → double

Constants

earthRadius → const double
maxLatitude → const double
minLatitude → const double