AnilocationTaskImpl class

Implemented types

Constructors

AnilocationTaskImpl({required AnilocationTaskDescription description})

Properties

description ↔ AnilocationTaskDescription
getter/setter pairoverride-getter
hashCode → int
The hash code for this object.
no setterinherited
isAnimating → bool
no setteroverride
isCompleted → bool
no setteroverride
isCompletedOrDismissed → bool
no setteroverride
isDismissed → bool
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → ILatLng
no setteroverride

Methods

animatePoints({ILatLng last = const ILatLng.empty()}) → void
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push(ILatLng latLng) → Future<void>
override
toString() → String
A string representation of this object.
inherited
updateActiveTrip(bool isActiveTrip) → void
override
updateRadius(double radius) → void
override
updateUseRotation(bool useRotation) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited